@@ -87,7 +87,7 @@ class Service:
         return self.bpm.call("EBHBPMService.now", body={})
 
     def nextBusinessKey(self, processKey: str):
-        return self.bpm.call("EBHBPMService.now", body={"processKey": processKey})
+        return self.bpm.call("EBHBPMService.nextBusinessKey", body={"processKey": processKey})
 
     def today(self):
         return self.bpm.call("EBHBPMService.today", body={})
@@ -401,3 +401,7 @@ class ExecutionService:
         process_instance_id = self.bpm.context.getValue('execution.getProcessInstanceId()')
         self.bpm.call("EBHBPMRuntime.removeVariable",
                       body={"executionId": process_instance_id, "variableName": variableName})
+
+    def getProcessInstanceId(self, variableName: str):
+        process_instance_id = self.bpm.context.getValue('execution.getProcessInstanceId()')
+        return process_instance_id
